@@ -9,7 +9,7 @@ import xarray as xr
 
 
 def correct_mpl(
-    obj,
+    ds,
     co_pol_var_name='signal_return_co_pol',
     cross_pol_var_name='signal_return_cross_pol',
     co_pol_afterpuls_var_name='afterpulse_correction_co_pol',
@@ -41,14 +41,14 @@ def correct_mpl(
 
     Parameters
     ----------
-    obj : Xarray Dataset
-        The ACT Xarray Dataset containg data
+    ds : xarray.Dataset
+        The Xarray Dataset containing data
     co_pol_var_name : str
         The Co-polar variable name used in Dataset
     cross_pol_var_name : str
         The Cross-polar variable name used in Dataset
     co_pol_afterpuls_var_name : str
-        The Co-polar after pluse variable name used in Dataset
+        The Co-polar after pulse variable name used in Dataset
     cross_pol_afterpulse_var_name : str
         The Cross-polar afterpulse variable name used in Dataset
     overlap_corr_var_name : str
@@ -65,43 +65,44 @@ def correct_mpl(
 
     Returns
     -------
-    obj : Xarray Dataset
-        The ACT Object containing the corrected values. The orginal Xarray Dataset
+    ds : xarray.Dataset
+        Xarray dataset containing the corrected values. The original Xarray Dataset
         passed in is modified.
 
     """
 
-    data_dims = obj[co_pol_var_name].dims
+    data_dims = ds[co_pol_var_name].dims
 
     # Overlap Correction Variable
-    op = obj[overlap_corr_var_name].values
+    op = ds[overlap_corr_var_name].values
     if len(op.shape) > 1:
         op = op[0, :]
 
-    op_height = obj[overlap_corr_heights_var_name].values
+    op_height = ds[overlap_corr_heights_var_name].values
     if len(op_height.shape) > 1:
         op_height = op_height[0, :]
 
-    # Check if height has dimentionality of time and height. If so reduce height
-    # to only dimentionality of height in object before removing values less than 0.
-    if len(obj[height_var_name].shape) > 1:
-        reduce_dim_name = {'time'} & set(obj[height_var_name].dims)
-        obj[height_var_name] = obj[height_var_name].reduce(
+    # Check if height has dimentionality of time and height. If so reduce
+    # height to only dimentionality of height in the dataset before removing
+    # values less than 0.
+    if len(ds[height_var_name].shape) > 1:
+        reduce_dim_name = {'time'} & set(ds[height_var_name].dims)
+        ds[height_var_name] = ds[height_var_name].reduce(
             func=np.median, dim=reduce_dim_name, keep_attrs=True
         )
 
     # 1 - Remove negative height data
-    obj = obj.where(obj[height_var_name] > 0.0, drop=True)
-    height = obj[height_var_name].values
+    ds = ds.where(ds[height_var_name] > 0.0, drop=True)
+    height = ds[height_var_name].values
 
     # Get indices for calculating background
-    if len(obj.height.shape) > 1:
-        ind = [obj.height.shape[1] - 50, obj.height.shape[1] - 2]
+    if len(ds.height.shape) > 1:
+        ind = [ds.height.shape[1] - 50, ds.height.shape[1] - 2]
     else:
-        ind = [obj.height.shape[0] - 50, obj.height.shape[0] - 2]
+        ind = [ds.height.shape[0] - 50, ds.height.shape[0] - 2]
 
     # Subset last gates into new dataset
-    dummy = obj.isel(range_bins=xr.DataArray(np.arange(ind[0], ind[1])))
+    dummy = ds.isel(range_bins=xr.DataArray(np.arange(ind[0], ind[1])))
 
     # Turn off warnings
     warnings.filterwarnings('ignore')
@@ -116,23 +117,23 @@ def correct_mpl(
     x_bg = x_bg.mean(dim='dim_0').values
 
     # Seems to be the fastest way of removing background signal at the moment
-    co_data = obj[co_pol_var_name].where(obj[co_pol_var_name] > 0).values
-    x_data = obj[cross_pol_var_name].where(obj[cross_pol_var_name] > 0).values
-    for i in range(len(obj['time'].values)):
+    co_data = ds[co_pol_var_name].where(ds[co_pol_var_name] > 0).values
+    x_data = ds[cross_pol_var_name].where(ds[cross_pol_var_name] > 0).values
+    for i in range(len(ds['time'].values)):
         co_data[i, :] = co_data[i, :] - co_bg[i]
         x_data[i, :] = x_data[i, :] - x_bg[i]
 
     # After Pulse Correction Variable
-    co_ap = obj[co_pol_afterpuls_var_name].values
+    co_ap = ds[co_pol_afterpuls_var_name].values
     # Fix dimentionality if backwards
-    co_ap_dims = obj[co_pol_afterpuls_var_name].dims
+    co_ap_dims = ds[co_pol_afterpuls_var_name].dims
     if len(co_ap_dims) > 1 and co_ap_dims[::-1] == data_dims:
         co_ap = np.transpose(co_ap)
 
-    x_ap = obj[cross_pol_afterpulse_var_name].values
+    x_ap = ds[cross_pol_afterpulse_var_name].values
 
     # Fix dimentionality if backwards
-    x_ap_dims = obj[cross_pol_afterpulse_var_name].dims
+    x_ap_dims = ds[cross_pol_afterpulse_var_name].dims
     if len(x_ap_dims) > 1 and x_ap_dims[::-1] == data_dims:
         x_ap = np.transpose(x_ap)
 
@@ -145,7 +146,7 @@ def correct_mpl(
     x_data = x_data * height**2
 
     # Overlap Correction
-    for j in range(obj[range_bins_var_name].size):
+    for j in range(ds[range_bins_var_name].size):
         if len(height.shape) > 1:
             idx = (np.abs(op_height - height[0, j])).argmin()
         else:
@@ -158,12 +159,12 @@ def correct_mpl(
     # Create the co/cross ratio variable
     if ratio_var_name is not None:
         ratio = (x_data / (x_data + co_data)) * 100.0
-        obj[ratio_var_name] = obj[co_pol_var_name].copy(data=ratio)
-        obj[ratio_var_name].attrs['long_name'] = 'Cross-pol / Co-pol ratio * 100'
-        obj[ratio_var_name].attrs['units'] = 'LDR'
+        ds[ratio_var_name] = ds[co_pol_var_name].copy(data=ratio)
+        ds[ratio_var_name].attrs['long_name'] = 'Cross-pol / Co-pol ratio * 100'
+        ds[ratio_var_name].attrs['units'] = 'LDR'
         try:
-            del obj[ratio_var_name].attrs['ancillary_variables']
-            del obj[ratio_var_name].attrs['description']
+            del ds[ratio_var_name].attrs['ancillary_variables']
+            del ds[ratio_var_name].attrs['description']
         except KeyError:
             pass
 
@@ -171,12 +172,12 @@ def correct_mpl(
     co_data = 10.0 * np.log10(co_data)
     x_data = 10.0 * np.log10(x_data)
 
-    # Write data to object
-    obj[co_pol_var_name].values = co_data
-    obj[cross_pol_var_name].values = x_data
+    # Write data to Xarray dataset
+    ds[co_pol_var_name].values = co_data
+    ds[cross_pol_var_name].values = x_data
 
     # Update units
-    obj[co_pol_var_name].attrs['units'] = f"10 * log10({obj[co_pol_var_name].attrs['units']})"
-    obj[cross_pol_var_name].attrs['units'] = f"10 * log10({obj[cross_pol_var_name].attrs['units']})"
+    ds[co_pol_var_name].attrs['units'] = f"10 * log10({ds[co_pol_var_name].attrs['units']})"
+    ds[cross_pol_var_name].attrs['units'] = f"10 * log10({ds[cross_pol_var_name].attrs['units']})"
 
-    return obj
+    return ds
