@@ -83,21 +83,21 @@ def test_add_in_nan():
 
 
 def test_get_missing_value():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
     missing = act.utils.data_utils.get_missing_value(
-        obj, 'latent_heat_flux', use_FillValue=True, add_if_missing_in_obj=True
+        ds, 'latent_heat_flux', use_FillValue=True, add_if_missing_in_ds=True
     )
     assert missing == -9999
 
-    obj['latent_heat_flux'].attrs['missing_value'] = -9998
-    missing = act.utils.data_utils.get_missing_value(obj, 'latent_heat_flux')
+    ds['latent_heat_flux'].attrs['missing_value'] = -9998
+    missing = act.utils.data_utils.get_missing_value(ds, 'latent_heat_flux')
     assert missing == -9998
 
 
 def test_convert_units():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
-    data = obj['soil_temp_1'].values
-    in_units = obj['soil_temp_1'].attrs['units']
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
+    data = ds['soil_temp_1'].values
+    in_units = ds['soil_temp_1'].attrs['units']
     r_data = act.utils.data_utils.convert_units(data, in_units, 'K')
     assert np.ceil(r_data[0]) == 285
 
@@ -105,22 +105,22 @@ def test_convert_units():
     assert np.ceil(data[0]) == 12
 
     try:
-        obj.utils.change_units()
+        ds.utils.change_units()
     except ValueError as error:
         assert str(error) == "Need to provide 'desired_unit' keyword for .change_units() method"
 
     desired_unit = 'degF'
-    skip_vars = [ii for ii in obj.data_vars if ii.startswith('qc_')]
-    obj.utils.change_units(
+    skip_vars = [ii for ii in ds.data_vars if ii.startswith('qc_')]
+    ds.utils.change_units(
         variables=None,
         desired_unit=desired_unit,
         skip_variables=skip_vars,
         skip_standard=True,
     )
     units = []
-    for var_name in obj.data_vars:
+    for var_name in ds.data_vars:
         try:
-            units.append(obj[var_name].attrs['units'])
+            units.append(ds[var_name].attrs['units'])
         except KeyError:
             pass
     indices = [i for i, x in enumerate(units) if x == desired_unit]
@@ -128,30 +128,30 @@ def test_convert_units():
 
     var_name = 'home_signal_15'
     desired_unit = 'V'
-    obj.utils.change_units(var_name, desired_unit, skip_variables='lat')
-    assert obj[var_name].attrs['units'] == desired_unit
+    ds.utils.change_units(var_name, desired_unit, skip_variables='lat')
+    assert ds[var_name].attrs['units'] == desired_unit
 
     var_names = ['home_signal_15', 'home_signal_30']
-    obj.utils.change_units(var_names, desired_unit)
+    ds.utils.change_units(var_names, desired_unit)
     for var_name in var_names:
-        assert obj[var_name].attrs['units'] == desired_unit
+        assert ds[var_name].attrs['units'] == desired_unit
 
-    obj.close()
-    del obj
+    ds.close()
+    del ds
 
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_CEIL1)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_CEIL1)
     var_name = 'range'
     desired_unit = 'km'
-    obj = obj.utils.change_units(var_name, desired_unit)
-    assert obj[var_name].attrs['units'] == desired_unit
-    assert np.isclose(np.sum(obj[var_name].values), 952.56, atol=0.01)
+    ds = ds.utils.change_units(var_name, desired_unit)
+    assert ds[var_name].attrs['units'] == desired_unit
+    assert np.isclose(np.sum(ds[var_name].values), 952.56, atol=0.01)
 
-    obj.close()
-    del obj
+    ds.close()
+    del ds
 
 
 def test_ts_weighted_average():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET_WILDCARD)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET_WILDCARD)
     cf_ds = {
         'sgpmetE13.b1': {
             'variable': [
@@ -160,7 +160,7 @@ def test_ts_weighted_average():
                 'pwd_precip_rate_mean_1min',
             ],
             'weight': [0.8, 0.15, 0.05],
-            'object': obj,
+            'ds': ds,
         }
     }
     data = act.utils.data_utils.ts_weighted_average(cf_ds)
@@ -169,35 +169,35 @@ def test_ts_weighted_average():
 
 
 def test_accum_precip():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET_WILDCARD)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET_WILDCARD)
 
-    obj = act.utils.accumulate_precip(obj, 'tbrg_precip_total')
-    dmax = round(np.nanmax(obj['tbrg_precip_total_accumulated']))
+    ds = act.utils.accumulate_precip(ds, 'tbrg_precip_total')
+    dmax = round(np.nanmax(ds['tbrg_precip_total_accumulated']))
     assert dmax == 13.0
 
-    obj = act.utils.accumulate_precip(obj, 'tbrg_precip_total', time_delta=60)
-    dmax = round(np.nanmax(obj['tbrg_precip_total_accumulated']))
+    ds = act.utils.accumulate_precip(ds, 'tbrg_precip_total', time_delta=60)
+    dmax = round(np.nanmax(ds['tbrg_precip_total_accumulated']))
     assert dmax == 13.0
 
-    obj['tbrg_precip_total'].attrs['units'] = 'mm/hr'
-    obj = act.utils.accumulate_precip(obj, 'tbrg_precip_total')
-    dmax = np.round(np.nanmax(obj['tbrg_precip_total_accumulated']), 2)
+    ds['tbrg_precip_total'].attrs['units'] = 'mm/hr'
+    ds = act.utils.accumulate_precip(ds, 'tbrg_precip_total')
+    dmax = np.round(np.nanmax(ds['tbrg_precip_total_accumulated']), 2)
     assert dmax == 0.22
 
 
 def test_calc_cog_sog():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_NAV)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_NAV)
 
-    obj = act.utils.calc_cog_sog(obj)
+    ds = act.utils.calc_cog_sog(ds)
 
-    cog = obj['course_over_ground'].values
-    sog = obj['speed_over_ground'].values
+    cog = ds['course_over_ground'].values
+    sog = ds['speed_over_ground'].values
 
     np.testing.assert_almost_equal(cog[10], 170.987, decimal=3)
     np.testing.assert_almost_equal(sog[15], 0.448, decimal=3)
 
-    obj = obj.rename({'lat': 'latitude', 'lon': 'longitude'})
-    obj = act.utils.calc_cog_sog(obj)
+    ds = ds.rename({'lat': 'latitude', 'lon': 'longitude'})
+    ds = act.utils.calc_cog_sog(ds)
     np.testing.assert_almost_equal(cog[10], 170.987, decimal=3)
     np.testing.assert_almost_equal(sog[15], 0.448, decimal=3)
 
@@ -254,20 +254,20 @@ def test_calculate_dqr_times():
 
 
 def test_decode_present_weather():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
-    obj = act.utils.decode_present_weather(obj, variable='pwd_pw_code_inst')
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
+    ds = act.utils.decode_present_weather(ds, variable='pwd_pw_code_inst')
 
-    data = obj['pwd_pw_code_inst_decoded'].values
+    data = ds['pwd_pw_code_inst_decoded'].values
     result = 'No significant weather observed'
     assert data[0] == result
     assert data[100] == result
     assert data[600] == result
 
-    np.testing.assert_raises(ValueError, act.utils.inst_utils.decode_present_weather, obj)
+    np.testing.assert_raises(ValueError, act.utils.inst_utils.decode_present_weather, ds)
     np.testing.assert_raises(
         ValueError,
         act.utils.inst_utils.decode_present_weather,
-        obj,
+        ds,
         variable='temp_temp',
     )
 
@@ -296,11 +296,11 @@ def test_datetime64_to_datetime():
 @pytest.mark.skipif(not PYART_AVAILABLE, reason="Py-ART is not installed.")
 def test_create_pyart_obj():
     try:
-        obj = act.io.mpl.read_sigma_mplv5(act.tests.EXAMPLE_SIGMA_MPLV5)
+        ds = act.io.mpl.read_sigma_mplv5(act.tests.EXAMPLE_SIGMA_MPLV5)
     except Exception:
         return
 
-    radar = act.utils.create_pyart_obj(obj, range_var='range')
+    radar = act.utils.create_pyart_obj(ds, range_var='range')
     variables = list(radar.fields)
     assert 'nrb_copol' in variables
     assert 'nrb_crosspol' in variables
@@ -331,41 +331,41 @@ def test_create_pyart_obj():
     np.testing.assert_allclose(
         gate_alt, [62.84009906, 63.8864653, 64.93293721, 65.9795148, 67.02619806]
     )
-    obj.close()
+    ds.close()
     del radar
 
 
 def test_add_solar_variable():
-    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_NAV)
-    new_obj = act.utils.geo_utils.add_solar_variable(obj)
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_NAV)
+    new_ds = act.utils.geo_utils.add_solar_variable(ds)
 
-    assert 'sun_variable' in list(new_obj.keys())
-    assert new_obj['sun_variable'].values[10] == 1
-    assert np.sum(new_obj['sun_variable'].values) >= 598
+    assert 'sun_variable' in list(new_ds.keys())
+    assert new_ds['sun_variable'].values[10] == 1
+    assert np.sum(new_ds['sun_variable'].values) >= 598
 
-    new_obj = act.utils.geo_utils.add_solar_variable(obj, dawn_dusk=True)
-    assert 'sun_variable' in list(new_obj.keys())
-    assert new_obj['sun_variable'].values[10] == 1
-    assert np.sum(new_obj['sun_variable'].values) >= 1234
+    new_ds = act.utils.geo_utils.add_solar_variable(ds, dawn_dusk=True)
+    assert 'sun_variable' in list(new_ds.keys())
+    assert new_ds['sun_variable'].values[10] == 1
+    assert np.sum(new_ds['sun_variable'].values) >= 1234
 
-    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_MET1)
-    new_obj = act.utils.geo_utils.add_solar_variable(obj, dawn_dusk=True)
-    assert np.sum(new_obj['sun_variable'].values) >= 1046
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_MET1)
+    new_ds = act.utils.geo_utils.add_solar_variable(ds, dawn_dusk=True)
+    assert np.sum(new_ds['sun_variable'].values) >= 1046
 
-    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_IRTSST)
-    obj = obj.fillna(0)
-    new_obj = act.utils.geo_utils.add_solar_variable(obj)
-    assert np.sum(new_obj['sun_variable'].values) >= 12
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_IRTSST)
+    ds = ds.fillna(0)
+    new_ds = act.utils.geo_utils.add_solar_variable(ds)
+    assert np.sum(new_ds['sun_variable'].values) >= 12
 
-    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_IRTSST)
-    obj.drop_vars('lat')
-    pytest.raises(ValueError, act.utils.geo_utils.add_solar_variable, obj)
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_IRTSST)
+    ds.drop_vars('lat')
+    pytest.raises(ValueError, act.utils.geo_utils.add_solar_variable, ds)
 
-    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_IRTSST)
-    obj.drop_vars('lon')
-    pytest.raises(ValueError, act.utils.geo_utils.add_solar_variable, obj)
-    obj.close()
-    new_obj.close()
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_IRTSST)
+    ds.drop_vars('lon')
+    pytest.raises(ValueError, act.utils.geo_utils.add_solar_variable, ds)
+    ds.close()
+    new_ds.close()
 
 
 def test_reduce_time_ranges():
@@ -393,12 +393,12 @@ def test_planck_converter():
 
 def test_solar_azimuth_elevation():
 
-    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_NAV)
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_NAV)
 
     elevation, azimuth, distance = act.utils.geo_utils.get_solar_azimuth_elevation(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
-        time=obj['time'].values,
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
+        time=ds['time'].values,
         library='skyfield',
         temperature_C='standard',
         pressure_mbar='standard',
@@ -410,12 +410,12 @@ def test_solar_azimuth_elevation():
 
 def test_get_sunrise_sunset_noon():
 
-    obj = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_NAV)
+    ds = act.io.armfiles.read_netcdf(act.tests.EXAMPLE_NAV)
 
     sunrise, sunset, noon = act.utils.geo_utils.get_sunrise_sunset_noon(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
-        date=obj['time'].values[0],
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
+        date=ds['time'].values[0],
         library='skyfield',
     )
     assert sunrise[0].replace(microsecond=0) == datetime(2018, 1, 31, 22, 36, 32)
@@ -423,9 +423,9 @@ def test_get_sunrise_sunset_noon():
     assert noon[0].replace(microsecond=0) == datetime(2018, 2, 1, 8, 2, 10)
 
     sunrise, sunset, noon = act.utils.geo_utils.get_sunrise_sunset_noon(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
-        date=obj['time'].values[0],
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
+        date=ds['time'].values[0],
         library='skyfield',
         timezone=True,
     )
@@ -434,8 +434,8 @@ def test_get_sunrise_sunset_noon():
     assert noon[0].replace(microsecond=0) == datetime(2018, 2, 1, 8, 2, 10, tzinfo=pytz.UTC)
 
     sunrise, sunset, noon = act.utils.geo_utils.get_sunrise_sunset_noon(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
         date='20180201',
         library='skyfield',
     )
@@ -444,8 +444,8 @@ def test_get_sunrise_sunset_noon():
     assert noon[0].replace(microsecond=0) == datetime(2018, 2, 1, 8, 2, 10)
 
     sunrise, sunset, noon = act.utils.geo_utils.get_sunrise_sunset_noon(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
         date=['20180201'],
         library='skyfield',
     )
@@ -454,8 +454,8 @@ def test_get_sunrise_sunset_noon():
     assert noon[0].replace(microsecond=0) == datetime(2018, 2, 1, 8, 2, 10)
 
     sunrise, sunset, noon = act.utils.geo_utils.get_sunrise_sunset_noon(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
         date=datetime(2018, 2, 1),
         library='skyfield',
     )
@@ -464,8 +464,8 @@ def test_get_sunrise_sunset_noon():
     assert noon[0].replace(microsecond=0) == datetime(2018, 2, 1, 8, 2, 10)
 
     sunrise, sunset, noon = act.utils.geo_utils.get_sunrise_sunset_noon(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
         date=datetime(2018, 2, 1, tzinfo=pytz.UTC),
         library='skyfield',
     )
@@ -474,8 +474,8 @@ def test_get_sunrise_sunset_noon():
     assert noon[0].replace(microsecond=0) == datetime(2018, 2, 1, 8, 2, 10)
 
     sunrise, sunset, noon = act.utils.geo_utils.get_sunrise_sunset_noon(
-        latitude=obj['lat'].values[0],
-        longitude=obj['lon'].values[0],
+        latitude=ds['lat'].values[0],
+        longitude=ds['lon'].values[0],
         date=[datetime(2018, 2, 1)],
         library='skyfield',
     )
@@ -492,76 +492,76 @@ def test_get_sunrise_sunset_noon():
 
 
 def test_is_sun_visible():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_EBBR1)
     result = act.utils.geo_utils.is_sun_visible(
-        latitude=obj['lat'].values,
-        longitude=obj['lon'].values,
-        date_time=obj['time'].values,
+        latitude=ds['lat'].values,
+        longitude=ds['lon'].values,
+        date_time=ds['time'].values,
     )
     assert len(result) == 48
     assert sum(result) == 20
 
     result = act.utils.geo_utils.is_sun_visible(
-        latitude=obj['lat'].values,
-        longitude=obj['lon'].values,
-        date_time=obj['time'].values[0],
+        latitude=ds['lat'].values,
+        longitude=ds['lon'].values,
+        date_time=ds['time'].values[0],
     )
     assert result == [False]
 
     result = act.utils.geo_utils.is_sun_visible(
-        latitude=obj['lat'].values,
-        longitude=obj['lon'].values,
+        latitude=ds['lat'].values,
+        longitude=ds['lon'].values,
         date_time=[datetime(2019, 11, 25, 13, 30, 00)],
     )
     assert result == [True]
 
     result = act.utils.geo_utils.is_sun_visible(
-        latitude=obj['lat'].values,
-        longitude=obj['lon'].values,
+        latitude=ds['lat'].values,
+        longitude=ds['lon'].values,
         date_time=datetime(2019, 11, 25, 13, 30, 00),
     )
     assert result == [True]
 
 
 def test_convert_to_potential_temp():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
 
     temp_var_name = 'temp_mean'
     press_var_name = 'atmos_pressure'
     temp = act.utils.data_utils.convert_to_potential_temp(
-        obj, temp_var_name, press_var_name=press_var_name
+        ds, temp_var_name, press_var_name=press_var_name
     )
     assert np.isclose(np.nansum(temp), -4240.092, rtol=0.001, atol=0.001)
     temp = act.utils.data_utils.convert_to_potential_temp(
-        temperature=obj[temp_var_name].values,
-        pressure=obj[press_var_name].values,
-        temp_var_units=obj[temp_var_name].attrs['units'],
-        press_var_units=obj[press_var_name].attrs['units'],
+        temperature=ds[temp_var_name].values,
+        pressure=ds[press_var_name].values,
+        temp_var_units=ds[temp_var_name].attrs['units'],
+        press_var_units=ds[press_var_name].attrs['units'],
     )
     assert np.isclose(np.nansum(temp), -4240.092, rtol=0.001, atol=0.0011)
 
     with np.testing.assert_raises(ValueError):
         temp = act.utils.data_utils.convert_to_potential_temp(
-            temperature=obj[temp_var_name].values,
-            pressure=obj[press_var_name].values,
-            temp_var_units=obj[temp_var_name].attrs['units'],
+            temperature=ds[temp_var_name].values,
+            pressure=ds[press_var_name].values,
+            temp_var_units=ds[temp_var_name].attrs['units'],
         )
 
     with np.testing.assert_raises(ValueError):
         temp = act.utils.data_utils.convert_to_potential_temp(
-            temperature=obj[temp_var_name].values,
-            pressure=obj[press_var_name].values,
-            press_var_units=obj[press_var_name].attrs['units'],
+            temperature=ds[temp_var_name].values,
+            pressure=ds[press_var_name].values,
+            press_var_units=ds[press_var_name].attrs['units'],
         )
 
 
 def test_height_adjusted_temperature():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
 
     temp_var_name = 'temp_mean'
     press_var_name = 'atmos_pressure'
     temp = act.utils.data_utils.height_adjusted_temperature(
-        obj,
+        ds,
         temp_var_name,
         height_difference=100,
         height_units='m',
@@ -570,12 +570,12 @@ def test_height_adjusted_temperature():
     assert np.isclose(np.nansum(temp), -6834.291, rtol=0.001, atol=0.001)
 
     temp = act.utils.data_utils.height_adjusted_temperature(
-        obj, temp_var_name=temp_var_name, height_difference=-900, height_units='feet'
+        ds, temp_var_name=temp_var_name, height_difference=-900, height_units='feet'
     )
     assert np.isclose(np.nansum(temp), -1904.7257, rtol=0.001, atol=0.001)
 
     temp = act.utils.data_utils.height_adjusted_temperature(
-        obj,
+        ds,
         temp_var_name,
         height_difference=-200,
         height_units='m',
@@ -588,10 +588,10 @@ def test_height_adjusted_temperature():
     temp = act.utils.data_utils.height_adjusted_temperature(
         height_difference=25.2,
         height_units='m',
-        temperature=obj[temp_var_name].values,
-        temp_var_units=obj[temp_var_name].attrs['units'],
-        pressure=obj[press_var_name].values,
-        press_var_units=obj[press_var_name].attrs['units'],
+        temperature=ds[temp_var_name].values,
+        temp_var_units=ds[temp_var_name].attrs['units'],
+        pressure=ds[press_var_name].values,
+        press_var_units=ds[press_var_name].attrs['units'],
     )
     assert np.isclose(np.nansum(temp), -5847.511, rtol=0.001, atol=0.001)
 
@@ -599,27 +599,27 @@ def test_height_adjusted_temperature():
         temp = act.utils.data_utils.height_adjusted_temperature(
             height_difference=25.2,
             height_units='m',
-            temperature=obj[temp_var_name].values,
+            temperature=ds[temp_var_name].values,
             temp_var_units=None,
-            pressure=obj[press_var_name].values,
-            press_var_units=obj[press_var_name].attrs['units'],
+            pressure=ds[press_var_name].values,
+            press_var_units=ds[press_var_name].attrs['units'],
         )
 
 
 def test_height_adjusted_pressure():
-    obj = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
+    ds = act.io.armfiles.read_netcdf(act.tests.sample_files.EXAMPLE_MET1)
 
     press_var_name = 'atmos_pressure'
     temp = act.utils.data_utils.height_adjusted_pressure(
-        obj=obj, press_var_name=press_var_name, height_difference=20, height_units='m'
+        ds=ds, press_var_name=press_var_name, height_difference=20, height_units='m'
     )
     assert np.isclose(np.nansum(temp), 142020.83, rtol=0.001, atol=0.001)
 
     temp = act.utils.data_utils.height_adjusted_pressure(
         height_difference=-100,
         height_units='ft',
-        pressure=obj[press_var_name].values,
-        press_var_units=obj[press_var_name].attrs['units'],
+        pressure=ds[press_var_name].values,
+        press_var_units=ds[press_var_name].attrs['units'],
     )
     assert np.isclose(np.nansum(temp), 142877.69, rtol=0.001, atol=0.001)
 
@@ -627,7 +627,7 @@ def test_height_adjusted_pressure():
         temp = act.utils.data_utils.height_adjusted_pressure(
             height_difference=-100,
             height_units='ft',
-            pressure=obj[press_var_name].values,
+            pressure=ds[press_var_name].values,
             press_var_units=None,
         )
 
@@ -650,3 +650,13 @@ def test_date_parser_minute_second():
 
     output_format = parsed_date.strftime('%Y-%m-%dT%H:%M:%S.%f')[:-3] + 'Z'
     assert output_format == '2020-01-01T12:00:00.000Z'
+
+
+def test_adjust_timestamp():
+    file = act.tests.sample_files.EXAMPLE_EBBR1
+    ds = act.io.armfiles.read_netcdf(file)
+    ds = act.utils.datetime_utils.adjust_timestamp(ds)
+    assert ds['time'].values[0] == np.datetime64('2019-11-24T23:30:00.000000000')
+
+    ds = act.utils.datetime_utils.adjust_timestamp(ds, offset=-60 * 60)
+    assert ds['time'].values[0] == np.datetime64('2019-11-24T22:30:00.000000000')
